@@ -22,7 +22,7 @@ define('mailvelope/view-detail', [
             $('.mail-item.mail-detail[data-cid="' + cid + '"] .content').toggleClass('current', false);
             $('.mail-item.mail-detail[data-cid="' + cid + '"] .content:visible').toggleClass('current', true);
             // Draw inline from first attachment
-            if (baton.data.PGPInline === true) {
+            if (isInline(baton.data.attachments[0])) {
                 baton.stopPropagation();
                 var text = baton.data.attachments[0].content.replace(/<br>/g, '\r\n');
                 return renderMail(cid, text);
@@ -41,9 +41,17 @@ define('mailvelope/view-detail', [
         }
     });
 
+    function isInline(attachment) {
+        if (attachment && attachment.content) {
+            return (/----BEGIN PGP MESSAGE-----/).test(attachment.content);
+        }
+        return false;
+    }
+
     function renderMail(cid, text) {
         return mailvelope.createDisplayContainer('.mail-item.mail-detail[data-cid="' + cid + '"] .content.current', text)
             .done(function () {
+                $('.mail-item.mail-detail[data-cid="' + cid + '"]').find('[data-action="inplace-reply"]').hide();
                 resize(cid);
             }).fail(function (err) {
                 if (!err || err.code !== 'TIMEOUT') {
