@@ -19,8 +19,9 @@ define('oxguard/core/og_http', [
         $.ajax({
             url: url + params,
             type:'POST',
+            dataType: 'json',
             data: JSON.stringify(data),
-            contentType:'application/json; charset=utf-8',
+            contentType:'application/json; charset=utf-8;',
             success: function (rdata) {
                 def.resolve (rdata);
                 if ((_.now() - t0) > 1000) {
@@ -48,6 +49,7 @@ define('oxguard/core/og_http', [
             url: url + params,
             type:'PUT',
             data: JSON.stringify(data),
+            dataType: 'json',
             contentType:'application/json; charset=utf-8',
             success: function (rdata) {
                 def.resolve (rdata);
@@ -70,9 +72,8 @@ define('oxguard/core/og_http', [
     // Look for passwords in outgoing data.  If able, encrypt
     function post (url, params, data) {
         var def = $.Deferred();
-        params = params + '&session=' + ox.session;
         require (['oxguard/crypto/encr'], function (encr) {
-            if (window.oxguarddata && window.oxguarddata.pubkey !== undefined && data !== undefined) {
+            if (window.oxguarddata && window.oxguarddata.pubKey !== undefined && data !== undefined) {
                 if (data.password !== undefined) {
                     if (data.password !== '') {
                         var epass = encr.cryptPass(data.password);
@@ -82,18 +83,9 @@ define('oxguard/core/og_http', [
                         }
                     }
                 }
-                if (data.ox_password !== undefined) {
-                    if (data.ox_password !== '') {
-                        var oxpass = encr.cryptPass(data.ox_password);
-                        if (oxpass !== null) {
-                            data.e_ox_password = oxpass;
-                            delete data.ox_password;
-                        }
-                    }
-                }
                 if (data.encr_password !== undefined) {
                     if (data.encr_password !== '') {
-                        var encrpass = encr.cryptPass(data.ox_password);
+                        var encrpass = encr.cryptPass(data.encr_password);
                         if (encrpass !== null) {
                             data.e_encr_password = encrpass;
                             delete data.encr_password;
