@@ -8,10 +8,12 @@
  * Copyright (C) 2016-2020 OX Software GmbH
  */
 
-define('oxguard/mail/keymanager', ['oxguard/core/og_http'],
-    function (og_http) {
+define('oxguard/mail/keymanager', ['oxguard/core/og_http', 'gettext!oxguard', 'settings!io.ox/calendar'],
+    function (og_http, gt, calSettings) {
     'use strict';
 
+    var blackList;   // We only want to pull the blacklist once
+
     // Check the list of previously fetched key results to see if the email is there.  If so, return, otherwise query backend
     function checkRecips (email, baton) {
         var gkeys = baton.model.get('gkeys');
@@ -45,6 +47,13 @@ define('oxguard/mail/keymanager', ['oxguard/core/og_http'],
             pending: true
         };
         baton.model.get('gkeys').push(result);
+        if (isBlackListed(email)) {
+            require (['io.ox/core/notifications'], function (notifications) {
+                notifications.yell('error', gt('Mailing list / blocked email found.  Encrypted emails to this email will fail.  %s', email));
+            });
+            updateKeys (email, baton, 'fail');
+            return;
+        }
         var params = '&email=' + email + '&cid=' + ox.context_id + '&from=' +
         encodeURIComponent(baton.model.get('from')[1]) + '&userid=' + ox.user_id;
         og_http.get(ox.apiRoot + '/oxguard/pgpmail?action=getkey', params)
@@ -62,6 +71,14 @@ define('oxguard/mail/keymanager', ['oxguard/core/og_http'],
                         if (data.error)
                             notifications.yell('error', data.error);
                     });
+                    return;
+                }
+                if (data.expired === true) {
+                    updateKeys (email, baton, 'fail');
+                    require (['io.ox/core/notifications'], function (notifications) {
+                        notifications.yell('error', gt('The key for %s has expired.  You will not be able to send an encrypted email to this recipient.', data.email));
+                    });
+                    return;
                 }
                 if (data.pgp === true) {
                     updateKeys (email, baton, 'pgp');
@@ -79,6 +96,25 @@ define('oxguard/mail/keymanager', ['oxguard/core/og_http'],
         });
     }
 
+    // Check if email is in blacklist
+    function isBlackListed (email) {
+        if (!blackList) {  // Initialize blacklist
+            blackList = calSettings.get('participantBlacklist');
+            if (blackList) {
+                blackList = blackList.toLowerCase();
+            } else {
+                blackList = '';
+            }
+        }
+        if (blackList && blackList !== '') {
+            if (blackList.indexOf(email.toLowerCase()) > -1) {
+                return true;
+            }
+        }
+
+        return false;
+    }
+
     // Update the list of gkeys with the result
     function updateKeys (email, baton, result) {
         var gkeys = baton.model.get('gkeys');
@@ -103,6 +139,21 @@ define('oxguard/mail/keymanager', ['oxguard/core/og_http'],
         updateTokens(baton);
     }
 
+    // Delete specific email from gkeys array
+    function deleteRecip (email, baton) {
+        var gkeys = baton.model.get('gkeys');
+        var found = -1;
+        gkeys.forEach(function (key, i) {
+            if (key.email === email) {
+                found = i;
+            }
+        });
+        if (found > -1) {
+            gkeys.splice(found, 1);
+            baton.model.set('gkeys', gkeys);
+        }
+    }
+
     // Check if an email is located in gkeys
     function isPresent (email, recips) {
         for (var i = 0; i < recips.length; i++) {
@@ -160,7 +211,8 @@ define('oxguard/mail/keymanager', ['oxguard/core/og_http'],
         checkAll: checkAll,
         clean: clean,
         isGuest: isGuest,
-        getGuests: getGuests
+        getGuests: getGuests,
+        deleteRecip: deleteRecip
     };
 
 });
