@@ -58,9 +58,9 @@ define('oxguard/mail/oxguard_mail_compose_core', [
         if (!util.isGuardConfigured()) {
             if (!prompting) {
                 prompting = true;
-                require(['oxguard/oxguard_core'], function (core) {
+                require(['oxguard/oxguard_core', 'oxguard/core/createKeys'], function (core, keys) {
                     core.metrics('mail', 'create-keys-from-compose');
-                    core.createKeysWizard()
+                    keys.createKeysWizard()
                     .done(function () {
                         checkrecipient(baton);
                     })
@@ -93,6 +93,9 @@ define('oxguard/mail/oxguard_mail_compose_core', [
         baton.view.$el.find('.oxguard_key').hide();
         baton.view.$el.find('.oxguard_token').hide();
         baton.view.model.set('encrypt', false);
+        var security = baton.view.model.get('security');
+        security.encrypt = false;
+        baton.view.model.set('security', security);
         var format = baton.view.model.get('PGPFormat');
         if (format === 'inline' || format === 'i') {  // Deactivate the Format types if not encrypted
             baton.view.model.set('PGPFormat', 'i');
@@ -103,11 +106,9 @@ define('oxguard/mail/oxguard_mail_compose_core', [
 
     function lock(baton) {
 
-        if (baton.app) {
-            if (baton.app.autosave) {
-                window.clearTimeout(baton.app.autosave.timer);
-            }
-        }
+        var security = baton.view.model.get('security');
+        security.encrypt = true;
+        baton.view.model.set('security', security);
         if (_.device('smartphone')) {
             $('.btn-primary:visible').html((settings.get('advanced') ? gt ('Send Encrypted') : gt('Send Secure')));
         } else {
@@ -122,7 +123,6 @@ define('oxguard/mail/oxguard_mail_compose_core', [
         baton.view.$el.find('.oxguard_key').show();
         baton.view.$el.find('.oxguard_token').show();
         baton.view.model.set('encrypt', true);
-        updateTokens(baton);
         var format = baton.view.model.get('PGPFormat');
         if (format === 'i') {  // Activate the Format types if encrypted
             baton.view.model.set('PGPFormat', 'inline');
@@ -131,16 +131,7 @@ define('oxguard/mail/oxguard_mail_compose_core', [
         }
     }
 
-    function updateTokens(baton) {
-        baton.model.trigger('change:to', baton.model, baton.model.get('to'));
-        baton.model.trigger('change:cc', baton.model, baton.model.get('cc'));
-        baton.model.trigger('change:bcc', baton.model, baton.model.get('bcc'));
-    }
-
     return {
-        checkRecip: function (baton) {
-            checkrecipient(baton);
-        },
         lock: lock,
         hash: hash,
         unlock: unlock,
