@@ -5,13 +5,14 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * Copyright (C) Open-Xchange Inc., 2006-2011
+ * Copyright (C) 2016-2020 OX Software GmbH
  */
 define('oxguard/mail/pin', [
     'io.ox/core/tk/dialogs',
     'oxguard/mail/keymanager',
+    'oxguard/mail/mail_metrics',
     'gettext!oxguard'
-], function (dialogs, keyman, gt) {
+], function (dialogs, keyman, metrics, gt) {
     function showpin (baton) {
         var def = $.Deferred();
         var pin = getpin();
@@ -25,17 +26,19 @@ define('oxguard/mail/pin', [
             names = names  + v + '\r\n';
         });
         table.text(names);
-        message.append(gt('The new recipients listed below will be sent a password via email.  You can also require a seperate pin, which is displayed below'));
+        message.append(gt('The new recipients listed below will be sent a password via email.  You can also require a separate pin, which is displayed below.'));
         var pinlabel = $('<label class="pin">' + pin + '</label>');
-        var message2 = $('<p>').append(gt('You may deliver this pin any way you see fit, but we recommend doing it in a second method other than email (Phone, SMS, Skype, etc)'));
-        var message3 = $('<p>').append(gt('If you want this extra pin requirement, click OK'));
+        var message2 = $('<p>').append(gt('You may deliver this pin any way you see fit, but we recommend doing it in a second method other than email (Phone, SMS, Skype, etc).'));
+        var message3 = $('<p>').append(gt('If you want this extra pin requirement, click OK.'));
         dialog.getBody().append(message).append(pinlabel).append(message2).append(message3).append('<hr/>').append(tableMessage).append(table);
         dialog.addPrimaryButton('ok', gt('OK'), 'ok')
         .addButton('cancel', gt('Skip'), 'cancel')
         .on('ok', function () {
+            metrics.track ('guest-pin-added');
             def.resolve(pin);
         })
         .on('cancel', function () {
+            metrics.track ('guard-pin-skipped');
             def.reject();
         }).show();
         return (def);
