@@ -114,40 +114,54 @@ define('oxguard/pgp/publickeys', [
         e.preventDefault();
     }
 
+    // Guard sends seperate keys for each ID, consolidate by keyid
+    function consolidate (data) {
+        var newData = {};
+        for (var i = 0; i < data.length; i++) {
+            var id = data[i].ids.replace(/\s/g,'');
+            if (newData[id] === undefined) {
+                newData[id] = data[i];
+            } else {
+                if (newData[id].shared && !data[i].shared) {  // If this is owned and not shared, then should be used
+                    newData[id] = data[i];
+                }
+            }
+        }
+        return newData;
+    }
     function updateKeyTable(id, list) {
         var deferred = $.Deferred();
-        var date = new Date();
-        var params = '&userid=' + ox.user_id + '&cid=' + ox.context_id +
-        '&session=' + ox.session + '&ticks=' + date.getTime();
+        var params = '&userid=' + ox.user_id + '&cid=' + ox.context_id;
         if (list !== undefined && list !== 'undefined')  {
             params += '&emails=' + encodeURI(list);
         }
         // Send the request to the oxguard server for the encrypted content key to decrypt
         http.get(ox.apiRoot + '/oxguard/pgp?action=getpublist', params)
         .done(function (data) {
-            data = JSON.parse(data);
+            data = consolidate(JSON.parse(data));
             var showDelete = false;
             var newtable = $('<table id="keylisttable' + id + '">');
             //#. Table headers for list of keys, option for Details and to delete
-            var headers = $('<th>' + gt('Email') + '</th><th>' + gt('Key Ids') + '</th><th>' + gt('Details') + '</th><th class="KeyDelete">' + gt('Delete') + '</th>');
-            if (data.length > 0) {
+            var headers = $('<th scope="col">' + gt('Email') + '</th><th scope="col">' + gt('Key Ids') + '</th><th scope="col">' + gt('Details') + '</th><th class="KeyDelete" scope="col">' + gt('Delete') + '</th>');
+            if (data !== {}) {
                 newtable.append(headers);
-                for (var i = 0; i < data.length; i++) {
+                for (var i in data) {
                     var tr = $('<tr>');
                     if (data[i].guard === true || data[i].shared === true) tr.addClass('oxguard_key_share');
+                    if (data[i].expired === true) tr.css('color', 'red');
                     var email = data[i].email.replace(/>/gi,'&gt;').replace(/</gi,'&lt;');
-                    var td1 = $('<td class="oxguard_pubkeylist" title="' + email + '">');
+                    var td1 = $('<th scope="row" class="oxguard_pubkeylist" title="' + email + '">');
                     td1.append(email);
                     tr.append(td1);
                     var td2 = $('<td>');
                     td2.append(data[i].ids);
                     tr.append(td2);
                     var td4 = $('<td>');
-                    var search = $('<a class="pgpdetail" ids="' + data[i].ids + '" notowned="' + (((data[i].guard === true) || (data[i].shared === true)) ? 'true' : 'false') + '" href="#"><icon class="fa fa-search"/></a>');
+                    var search = $('<a class="pgpdetail" aria-label="' + gt('Details') + '" ids="' + data[i].ids + '" notowned="' + (((data[i].guard === true) || (data[i].shared === true)) ? 'true' : 'false') + '" href="#"><icon class="fa fa-search"/></a>');
                     td4.append(search);
                     var td5 = $('<td class="KeyDelete">');
                     if ((data[i].guard !== true) && (data[i].shared !== true)) {
-                        var del = $('<a href="#" value="' + data[i].ids + '" tableid="' + id + '" emaillist="' + list + '"><icon class="fa fa-trash"/></a>')
+                        var del = $('<a href="#" aria-label="' + gt('Delete') + '" value="' + data[i].ids + '" tableid="' + id + '" emaillist="' + list + '"><icon class="fa fa-trash"/></a>')
                         .click (deleteConfirm);
                         td5.append(del);
                         showDelete = true;
@@ -176,8 +190,7 @@ define('oxguard/pgp/publickeys', [
     }
 
     function showDetail (id, guard) {
-        var params = '&userid=' + ox.user_id + '&cid=' + ox.context_id + '&ids= ' + id + '&guard=' + guard +
-        '&session=' + ox.session;
+        var params = '&userid=' + ox.user_id + '&cid=' + ox.context_id + '&ids= ' + id + '&guard=' + guard;
         // Send the request to the oxguard server for the encrypted content key to decrypt
         var url = '/oxguard/pgp?action=getpubdetail';
         http.get(ox.apiRoot + url, params)
@@ -192,15 +205,15 @@ define('oxguard/pgp/publickeys', [
 
                 if ((data.length > 0) && (guard !== 'true')) { // we don't display share options for Guard created keys
                     var optionsdiv = $('<div class="keyoptions">');
-                    var sharingtext = $('<label>' + gt('Share Keys') + '</label>');
-                    var sharing = $('<input type="checkbox" value="' + keydetail.keyids + '" style="margin-right:15px;">');
+                    var sharingtext = $('<label for="pgpShare">' + gt('Share Keys') + '</label>');
+                    var sharing = $('<input id="pgpShare" type="checkbox" value="' + keydetail.keyids + '" style="margin-right:15px;">');
                     sharing.prop('checked', json.share > 0)
                     .on('click', changeShare);
                     sharingtext.click(function () {
                         sharing.click();
                     });
-                    var inlinetext = $('<label>' + gt('Use PGP Inline') + '</label>');
-                    var inline = $('<input type="checkbox" value="' + keydetail.keyids + '" style="margin-right:15px; margin-left:40px;">')
+                    var inlinetext = $('<label for="pgpInline">' + gt('Use PGP Inline') + '</label>');
+                    var inline = $('<input id="pgpInline" type="checkbox" value="' + keydetail.keyids + '" style="margin-right:15px; margin-left:40px;">')
                     .on('click', changeInline);
                     inline.prop('checked', json.inline);
                     inlinetext.click(function () {
@@ -241,7 +254,10 @@ define('oxguard/pgp/publickeys', [
             if (i > 0) resultdiv.append('<hr>');
             var detaildiv = $('<div style="padding-left:20px;">');
             //#. if key is "expired"
-            if (data[i].Expired) detaildiv.append('<b>' + gt('Expired') +'</b><br>');
+            if (data[i].Expired) {
+                detaildiv.append('<b>' + gt('Expired') +'</b><br>');
+                detaildiv.css('color', 'red');
+            }
             if (data[i].Revoked) detaildiv.append('<b style="color:red">' + gt('Revoked') +'</b><br>');
             //#. Fingeprint of the key
             detaildiv.append(gt('Fingerprint:') + ' ' + formatFingerprint(data[i].Fingerprint) + '<br>');
@@ -295,8 +311,7 @@ define('oxguard/pgp/publickeys', [
     }
 
     function showSignatures (id) {
-        var params = '&userid=' + ox.user_id + '&cid=' + ox.context_id + '&keyid= ' + id +
-        '&session=' + ox.session;
+        var params = '&userid=' + ox.user_id + '&cid=' + ox.context_id + '&keyid= ' + id;
         // Send the request to the oxguard server for the encrypted content key to decrypt
         var url = '/oxguard/pgp?action=getsignatures';
         http.get(ox.apiRoot + url, params)
@@ -394,7 +409,7 @@ define('oxguard/pgp/publickeys', [
         var tableHeader = $('<legend>');
         if (id == 'settings') tableHeader = $('<b>');
         tableHeader.append(gt('PGP Public Key List'));
-        var refresh = $('<a href="#" style="margin-left:10px;"><icon class="fa fa-refresh fa-spin refreshkeys"></a>')
+        var refresh = $('<a href="#" style="margin-left:10px;" aria-label="' + gt('Refresh') + '"><icon class="fa fa-refresh fa-spin refreshkeys"></a>')
             .click(function (e) {
                 $(this).addClass('fa-spin');
                 updateKeyTable(id, list).done(function () {
@@ -403,9 +418,9 @@ define('oxguard/pgp/publickeys', [
                 e.preventDefault();
             });
         var fileinput = $('<input type="file" name="publicKey" style="display:none;" multiple>');
-        var addKey = $('<a href="#" style="margin-left:10px;"><icon class="fa fa-plus" id="addpgppublickeys"></a>')
+        var addKey = $('<a href="#" style="margin-left:10px;" aria-label="' +
+            gt('Upload Public Key Only') + '"><icon class="fa fa-plus" id="addpgppublickeys"></a>')
         .click(function (e) {
-            fileinput.click();
             fileinput.unbind('change');
             fileinput.on('change', function () {
                 var files = this.files;
@@ -420,6 +435,7 @@ define('oxguard/pgp/publickeys', [
                     });
                 }
             });
+            fileinput.click();
             e.preventDefault();
         });
         tableHeader.append(refresh).append(fileinput).append(addKey);
