@@ -5,7 +5,7 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * Copyright (C) Open-Xchange Inc., 2006-2011
+ * Copyright (C) 2016-2020 OX Software GmbH
  */
 define('oxguard/pgp/settings', [
     'io.ox/core/extensions',
@@ -31,7 +31,8 @@ define('oxguard/pgp/settings', [
         var provider = settings.get('cryptoProvider');
 
         point.extend({
-            title: gt('Guard PGP Settings'),
+            //#. %s product name
+            title: gt('Advanced Settings'),
             id: 'oxguard/pgp',
             loadSettingPane: true,
             index: 100
