@@ -4,7 +4,7 @@ define('oxguard/pgp/settings/pane', [
     'oxguard/pgp/publickeys',
     'oxguard/core/og_http',
     'oxguard/util',
-    'oxguard/passwords',
+    'oxguard/core/passwords',
     'oxguard/oxguard_core',
     'settings!oxguard',
     'io.ox/backbone/mini-views/help',
@@ -37,7 +37,7 @@ define('oxguard/pgp/settings/pane', [
         header.append(new HelpView({
             base: 'help-guard',
             iconClass: 'guardhelp',
-            href: 'ox.guard.user.sect.settings.keys.html',
+            href: 'ox.guard.user.sect.usage.settings.keys.html',
             tabindex: '-1'
         }).render().$el);
         var pgpHeader = $('<div class="oxguard_settings keys"/>')
@@ -51,7 +51,7 @@ define('oxguard/pgp/settings/pane', [
     function userKeys() {
         var pubdiv = $('<div class="publicKeyDiv"/>');
         var tableHeader = $('<b>' + gt('Your Key List') + '</b>');
-        var refresh = $('<a href="#" style="margin-left:10px;"><icon class="fa fa-refresh fa-spin" id="refreshuserkeys"></a>')
+        var refresh = $('<a href="#" style="margin-left:10px;" aria-label="' + gt('Refresh') + '"><icon class="fa fa-refresh fa-spin" id="refreshuserkeys"></a>')
             .click(function (e) {
                 $(this).addClass('fa-spin');
                 updateUserKeyTable().done(function () {
@@ -59,7 +59,8 @@ define('oxguard/pgp/settings/pane', [
                 });
                 e.preventDefault();
             });
-        var addKey = $('<a href="#" style="margin-left:10px;"><icon class="fa fa-plus" id="adduserkeys"></a>')
+        var addKey = $('<a href="#" style="margin-left:10px;" aria-label="' +
+            gt('Create %s Security Keys', window.oxguarddata.productName) + '"><icon class="fa fa-plus" id="adduserkeys"></a>')
         .click(function (e) {
             uploadLocalKeysDialog();
             e.preventDefault();
@@ -88,43 +89,44 @@ define('oxguard/pgp/settings/pane', [
             grpdata = JSON.parse(grpdata);
             userKeyData = grpdata;
             var newtable = $('<table id="userkeytable">');
-            var headers = $('<th>' + gt('Key ID') + '</th><th>'  + gt('Private Key') + '</th><th>' + gt('Current') + '</th><th>' + gt('Details') + '</th><th>' + gt('Delete') + '</th><th>' + gt('Download') + '</th><th>' + gt('Edit') + '</th>' );
+            var headers = $('<th scope="col">' + gt('Key ID') + '</th><th scope="col">'  + gt('Private Key') + '</th><th scope="col">' + gt('Current') + '</th><th scope="col">' + gt('Details') + '</th><th scope="col">' + gt('Delete') + '</th><th scope="col">' + gt('Download') + '</th><th scope="col">' + gt('Edit') + '</th>' );
             if (grpdata.length !== 0) {
                 newtable.append(headers);
 
                 for (var grp = 0; grp < grpdata.length; grp++) {
                     var data = grpdata[grp];
                     for (var i = 0; i < data.length; i++) {
-                        var tr = data[i].Revoked ? $('<tr style="color:red; text-decoration:line-through;">') : $('<tr>');
-                        var td1 = $('<td style="text-align:left;">');
+                        var tr = (data[i].Revoked || data[i].Expired) ? $('<tr style="color:red;">') : $('<tr>');
+                        if (data[i].Revoked) $(tr).css('text-decoration', 'line-through');
+                        var td1 = $('<th scopre="row" style="text-align:left;">');
                         if (data[i].Master === false) {
                             td1.append('<i class="fa fa-level-up fa-rotate-90" style="padding-right:7px; vertical-align:bottom;"></i>');
                         }
                         td1.append($('<span style="padding-left:5px;">' + data[i].Key + '</span>'));
                         tr.append(td1);
                         var td2 = $('<td>');
-                        td2.append(data[i].hasPrivate ? '<icon class="fa fa-check"/>' : '');
+                        td2.append(data[i].hasPrivate ? '<icon class="fa fa-check" title="' + gt('Private Key') + '"/>' : '');
                         tr.append(td2);
                         var td3 = $('<td>');
                         if (data[i].current) {
-                            td3.append('<icon class="fa fa-check"/>');
+                            td3.append('<icon class="fa fa-check" title="' + gt('Current') + '"/>');
                         } else {
-                            var makecurrent = $('<input type="checkbox" class="makecurrent" value="' + data[i].GuardKey + '"/>');
+                            var makecurrent = $('<input type="checkbox" id="makeCurrent" aria-label="' + gt('Current') + '" class="makecurrent" value="' + data[i].GuardKey + '"/>');
                             td3.append(makecurrent);
                         }
 
                         tr.append(td3);
                         var td4 = $('<td>');
-                        var search = $('<a class="userpgpdetail" ids="' + grp + ',' + i + '" href="#"><icon class="fa fa-search"/></a>');
+                        var search = $('<a class="userpgpdetail" aria-label="' + gt('Details') + '" ids="' + grp + ',' + i + '" href="#"><icon class="fa fa-search"/></a>');
                         td4.append(search);
                         var td5 = $('<td>');
-                        var del = $('<a href="#" value="' + grp + ',' + i + '" class="delPriv"><icon class="fa fa-trash"/></a>');
+                        var del = $('<a href="#" aria-label="' + gt('Delete') + '" value="' + grp + ',' + i + '" class="delPriv"><icon class="fa fa-trash"/></a>');
                         td5.append(del);
                         var td6 = $('<td>');
-                        var down = $('<a class="keydownload" href="#" value="' + grp + ',' + i + '"><icon class="fa fa-download"/></a>');
+                        var down = $('<a class="keydownload" aria-label="' + gt('Download') + '" href="#" value="' + grp + ',' + i + '"><icon class="fa fa-download"/></a>');
                         td6.append(down);
                         var td7 = $('<td>');
-                        var edit = $('<a class="keyedit" href="#" value="' + data[i].KeyLong + '"><icon class="fa fa-pencil"/></a>');
+                        var edit = $('<a class="keyedit" aria-label="' + gt('Edit') + '" href="#" value="' + data[i].KeyLong + '"><icon class="fa fa-pencil"/></a>');
                         td7.append(edit);
                         tr.append(td4).append(td5).append(td6).append(td7);
                         newtable.append(tr);
@@ -182,7 +184,6 @@ define('oxguard/pgp/settings/pane', [
             var uploadheader = $('<p>' + gt('If you already have a private key, you can upload it here.') + '</p>');
             var uploadbutton = $('<button type="button" class="btn btn-primary">' + gt('Upload Private Key') + '</button>');
             uploadbutton.on('click', function () {
-                fileinput.click();
                 fileinput.unbind('change');
                 fileinput.on('change', function () {
                     var files = this.files;
@@ -199,6 +200,7 @@ define('oxguard/pgp/settings/pane', [
                         });
                     }
                 });
+                fileinput.click();
                 dialog.close();
             });
             var fileinput;
@@ -522,7 +524,7 @@ define('oxguard/pgp/settings/pane', [
             var downloadbutton = $('<button type="button" class="btn btn-primary">').text(gt('Download PGP Public Key'));
             downloadbutton.on('click', function () {
                 core.metrics('settings', 'download-public-key');
-                var params = '&id=' + ox.user_id + '&cid=' + ox.context_id + '&keyid=' + data.GuardKey;
+                var params = '&id=' + ox.user_id + '&cid=' + ox.context_id + '&keyid=' + data.GuardKey + '&session=' + ox.session;
                 window.open(ox.apiRoot + '/oxguard/pgpmail/public.asc?action=getkeybyid' + params, '_blank');
                 dialog.close();
             });
@@ -544,10 +546,15 @@ define('oxguard/pgp/settings/pane', [
             resultdiv.append(gt('Key ID:') + ' ' + formatKeyID(data.KeyID) + '<br><br>');
             var detaildiv = $('<div style="padding-left:20px;">');
             if (data.Expires !== 'never') {
-                var now = new Date();
-                var expires = new Date(now);
-                expires.setDate(now.getDate() + data.Expires);
-                detaildiv.append(gt('Expires:') + ' ' + expires.toDateString() + '<br>');
+                if (data.Expired === true) {
+                    detaildiv.append(gt('Expired') + '<br>');
+                    detaildiv.css('color', 'red');
+                } else {
+                    var now = new Date();
+                    var expires = new Date(now);
+                    expires.setDate(now.getDate() + data.Expires);
+                    detaildiv.append(gt('Expires:') + ' ' + expires.toDateString() + '<br>');
+                }
             }
             detaildiv.append(gt('Private Key: ') + (data.hasPrivate ? gt('True') : gt('False')) + '<br>');
             detaildiv.append(gt('Fingerprint:') + ' ' + formatFingerprint(data.Fingerprint) + '<br>');
@@ -601,9 +608,9 @@ define('oxguard/pgp/settings/pane', [
     }
 
     function createNew () {
-        require (['oxguard/oxguard_core', 'io.ox/core/notifications'], function (core, notify) {
+        require (['oxguard/oxguard_core', 'io.ox/core/notifications', 'oxguard/core/createKeys'], function (core, notify, keys) {
             core.metrics('settings', 'create-keys-new');
-            core.createKeys()
+            keys.createKeys()
             .done(function () {
                 updateUserKeyTable();
             })
@@ -656,7 +663,7 @@ define('oxguard/pgp/settings/pane', [
 
     function checkTempPassword (auth) {
         if (auth.indexOf('Password Needed') > -1) {
-            require (['oxguard/pgp/checker'], function (core) {
+            require (['oxguard/core/tempPassword'], function (core) {
                 core.createOxGuardPasswordPrompt();
             });
         }
@@ -677,7 +684,6 @@ define('oxguard/pgp/settings/pane', [
         }
         var uploadbutton = $('<button type="button" class="btn btn-primary">' + gt('Upload Public Key Only') + '</button>');
         uploadbutton.on('click', function () {
-            fileinput.click();
             fileinput.unbind('change');
             fileinput.on('change', function () {
                 var files = this.files;
@@ -695,6 +701,7 @@ define('oxguard/pgp/settings/pane', [
                     });
                 }
             });
+            fileinput.click();
             dialog.close();
         });
         uploadHeader.append(uploadbutton);
@@ -782,10 +789,12 @@ define('oxguard/pgp/settings/pane', [
         var defaultChecked = $('#pgpdefault').is(':checked');
         var defaultinline = $('#inlinedefault').is(':checked');
         var pgpsign = $('#pgpsign').is(':checked');
+        var encryptIncoming = $('#encrIncoming').is(':checked');
         var data = {
             pgpdefault: defaultChecked,
             inline: defaultinline,
-            pgpsign: pgpsign
+            pgpsign: pgpsign,
+            encryptIncoming: encryptIncoming
         };
         window.oxguarddata.settings = _.extend(window.oxguarddata.settings, data);
         var json = {
@@ -818,12 +827,22 @@ define('oxguard/pgp/settings/pane', [
             } else {
                 $('#pgpsign').prop('checked', false);
             }
+            if (window.oxguarddata.settings.encryptIncoming) {
+                $('#encrIncoming').prop('checked', true);
+            } else {
+                $('#encrIncoming').prop('checked', false);
+            }
             if (settings.get('advanced')) {
                 $('#pgpadvanced').prop('checked', true);
             } else {
                 $('#pgpadvanced').prop('checked', false);
             }
         }
+        if (settings.get('defRemember')) {
+            $('#defrem').val(settings.get('defRemember'));
+        } else {
+            $('#defrem').val('0');
+        }
     }
 
     function switchEmailType () {
@@ -849,29 +868,58 @@ define('oxguard/pgp/settings/pane', [
 
     function defaults () {
         var defaultsHeader = $('<div class="oxguard_settings defaults" style="line-height: 1.8em;"/>');
+        var rememberDefault = $('<div class="row" style="padding-bottom:10px;">');
+        var remPass = $('<select id="defrem" class="form-control">' +
+                '<option value="0">' + gt('Ask each time') + '</option>' +
+                '<option value="10">' + gt('10 minutes') + '</option>' +
+                '<option value="20">' + gt('20 minutes') + '</option>' +
+                '<option value="30">' + gt('30 minutes') + '</option>' +
+                '<option value="60">' + gt('1 hour') + '</option>' +
+                '<option value="120">' + gt('2 hours') + '</option>' +
+                '<option value="99999">' + gt('Session') + '</option' +
+                '</select>')
+                .on('change', function (e) {
+                    if (e.target.value === 0) {
+                        settings.clear('defRemember');
+                    } else {
+                        settings.set('defRemember', e.target.value);
+                        settings.save();
+                    }
+                });
+        rememberDefault.append('<label for="defrem" class="control-lobal col-sm-4">' + gt('Remember Password Default') + '</label>')
+        .append($('<div class="col-sm-4">').append(remPass));
         var makePGPdefault = $('<input type="checkbox" id="pgpdefault" style="margin-right:15px; margin-top:1px;">');
         var optiondiv = $('<div>');
-        var defdiv = $('<span class="selectable">' + gt('Default to send encrypted when composing email') + '</span></br>');
+        var defdiv = $('<label class="selectable" for="pgpdefault">' + gt('Default to send encrypted when composing email') + '</span></br>');
         defdiv.click(function () {
             makePGPdefault.click();
         });
+        var encrDefault =  $('<input type="checkbox" id="encrIncoming" style="margin-right:15px; margin-top:1px;">');
+        var encrDiv = $('<label class="selectable" for="encrIncoming">' + gt('Encrypt all incoming emails') + '</span></br>');
+        encrDiv.click(function () {
+            encrDefault.click();
+        });
         var pGPSigndefault = $('<input type="checkbox" id="pgpsign" style="margin-right:15px; margin-top:1px;">');
-        var sigdiv = $('<span class="selectable">' + gt('Default adding signature to outgoing mails') + '</span></br>');
+        var sigdiv = $('<label class="selectable" for="pgpsign">' + gt('Default adding signature to outgoing mails') + '</span></br>');
         sigdiv.click(function () {
             pGPSigndefault.click();
         });
-        var typediv = $('<span class="selectable">' + gt('Default to using PGP inline for new mails') + '</span></br>');
+        var typediv = $('<label class="selectable" for="inlinedefault">' + gt('Default to using PGP inline for new mails') + '</span></br>');
         var pgpType = $('<input type="checkbox" id="inlinedefault" style="margin-right:15px; margin-top:1px;">');
         typediv.click(function () {
             pgpType.click();
         });
-        optiondiv.append(makePGPdefault).append(defdiv).append(pGPSigndefault).append(sigdiv);
-        if (settings.get('advanced')) {
+        optiondiv.append(rememberDefault).append(makePGPdefault).append(defdiv).append(pGPSigndefault).append(sigdiv);
+        if (settings.get('advanced') || window.oxguarddata.settings.inline) {
+            if (settings.get('enableEncryptIncoming')) optiondiv.append(encrDefault).append(encrDiv);
             optiondiv.append(pgpType).append(typediv);
         }
         makePGPdefault.click(function () {
             sendDefaults();
         });
+        encrDefault.click(function () {
+            sendDefaults();
+        });
         pgpType.click(function () {
             sendDefaults();
             switchEmailType();
@@ -900,7 +948,7 @@ define('oxguard/pgp/settings/pane', [
         var defaultsHeader = $('<div class="oxguard_settings defaults" style="line-height: 1.8em;"/>');
         var useAdvanced = $('<input type="checkbox" id="pgpadvanced" class="pgpadvanced" style="margin-right:15px; margin-top:1px;">');
         var optiondiv = $('<div>');
-        var advdiv = $('<span class="selectable pgpadvanced">' + gt('Enable Advanced PGP Features') + '</span></br>');
+        var advdiv = $('<label for="pgpadvanced" class="selectable pgpadvanced">' + gt('Enable Advanced PGP Features') + '</span></br>');
         advdiv.click(function () {
             useAdvanced.click();
         });
@@ -962,7 +1010,7 @@ define('oxguard/pgp/settings/pane', [
         message.append(new HelpView({
             base: 'help-guard',
             iconClass: 'guardhelp',
-            href: 'ox.guard.user.sect.settings.pgp.html',
+            href: 'ox.guard.user.sect.usage.settings.pgp.html',
             tabindex: '-1'
         }).render().$el);
         var header = $('<h1>').append(message);
