@@ -21,11 +21,13 @@ define('oxguard/settings/pane', [
         instructions.append('<p>' + gt('In order to start with %s Security, you must set up a password for your secured files.', window.oxguarddata.productName) + '</p>');
         var startButton = $('<button type="button" class="btn btn-primary">' + gt('Start') + '</button>');
         startButton.click (function () {
-            core.metrics('settings', 'create-keys');
-            core.createKeysWizard()
-            .done(function (result) {
-                if (result === 'OK') draw(where);
-                //$('.oxguard_settings').replaceWith(addSettings());
+            require(['oxguard/core/createKeys'], function (keys) {
+                core.metrics('settings', 'create-keys');
+                keys.createKeysWizard()
+                .done(function (result) {
+                    if (result === 'OK') draw(where);
+                    //$('.oxguard_settings').replaceWith(addSettings());
+                });
             });
         });
         var holder = $('<div>').css('max-width', '800px');
@@ -34,21 +36,30 @@ define('oxguard/settings/pane', [
         where.append(holder.append(passheader.append(instructions).append(startButton)));
     }
 
+    // Add click action to element if the user hits enter key
+    function checkEnter (element, clickEl) {
+        element.on('keyup', function (e) {
+            if (e.keyCode === 13) {
+                clickEl.click();
+            }
+        });
+    }
+
     function createPasswordChange() {
         var passheader =
         $('<div class="oxguard_settings password"/>')
         .append('<legend class="sectiontitle">' + gt('Password') + '</legend></br>')
         //#. %s product name
         .append('<span> ' + gt('Change %s Security Password.', window.oxguarddata.productName) + '</span><br/>');
-        var newpass1 = $('<input type="password" name="newpass1" autocomplete="off"/>');
+        var newpass1 = $('<input type="password" id="newpass1" name="newpass1" autocomplete="off"/>');
         var td = $('<td>').append(newpass1);
-        var newpass2 = $('<input type="password" name="newpass2" autocomplete="off"/>');
+        var newpass2 = $('<input type="password" id="newpass2" name="newpass2" autocomplete="off"/>');
         var td2 = $('<td>').append(newpass2);
         var hint = $('<td style="width:150px;">');
-        var curPrompt = $('<span>').append(gt('Enter current %s security password', window.oxguarddata.productName));
-        var prompt1 = $('<span>').append(gt('Enter new %s security password', window.oxguarddata.productName));
-        var prompt2 = $('<span>').append(gt('Verify new %s security password', window.oxguarddata.productName));
-        var oldpass = $('<input type="password" name="oldpass" autocomplete="off" />');
+        var curPrompt = $('<label for="oldpass">').append(gt('Enter current %s security password', window.oxguarddata.productName));
+        var prompt1 = $('<label for="newpass1">').append(gt('Enter new %s security password', window.oxguarddata.productName));
+        var prompt2 = $('<label for="newpass2">').append(gt('Verify new %s security password', window.oxguarddata.productName));
+        var oldpass = $('<input type="password" id="oldpass" name="oldpass" autocomplete="off" />');
         var passwordTable;
         if (_.device('small')) {
             passwordTable = $('<div style="padding:10px;">');
@@ -77,7 +88,7 @@ define('oxguard/settings/pane', [
         //#. %s product name
         var passButton = $('<button type="button" class="btn btn-primary" style="margin-top:10px;">' + gt('Change %s security password', window.oxguarddata.productName) + '</button>');
         passButton.click(passChanged);
-
+        checkEnter (newpass2, passButton);
         return (passheader.append(passwordTable).append(passButton));
     }
 
@@ -97,7 +108,7 @@ define('oxguard/settings/pane', [
     }
 
     function createDeleteRecovery() {
-        if (window.oxguarddata.settings.noDeleteRecovery || !window.oxguarddata.recovery) {
+        if (window.oxguarddata.settings.noDeleteRecovery || !window.oxguarddata.recovery || !settings.get('advanced')) {
             return ('');
         }
         var header = $('<div class="oxguard_settings"/>')
@@ -151,12 +162,12 @@ define('oxguard/settings/pane', [
             emailheader.append(current).append(currentEmail);
         }
         var noSaveWorkAround = $('<input style="display:none" type="text" name="dontremember"/><input style="display:none" type="password" name="dontrememberpass"/>');
-        var emailPass = $('<input name="newemail"/>');
-        var verifyPass = $('<input name="newemailverify">');
-        var currentPrompt = $('<span>').append(gt('Enter current %s security password', window.oxguarddata.productName));
-        var currentInput = $('<input type="password" name="ogpass" autocomplete="off"/>');
-        var newPrompt = $('<span>').append(gt('Enter new secondary Email address'));
-        var verifyPrompt = $('<span>').append(gt('Verify Email address'));
+        var emailPass = $('<input id="newemail" name="newemail"/>');
+        var verifyPass = $('<input id="newemailverify" name="newemailverify">');
+        var currentPrompt = $('<label for="ogpass">').append(gt('Enter current %s security password', window.oxguarddata.productName));
+        var currentInput = $('<input type="password" id="ogpass" name="ogpass" autocomplete="off"/>');
+        var newPrompt = $('<label for="newemail">').append(gt('Enter new secondary Email address'));
+        var verifyPrompt = $('<label for="newemailverify">').append(gt('Verify Email address'));
         var hint = $('<td>');
         var emailTable;
         if (_.device('small')) {
@@ -176,6 +187,7 @@ define('oxguard/settings/pane', [
         var emailButton = $('<button type="button" class="btn btn-primary">' + gt('Change Email address') + '</button>');
         verify.setValidate(emailPass, hint);
         verify.autoCompare(emailPass, verifyPass, hint);
+        checkEnter(verifyPass, emailButton);
         emailButton.click(emailChanged);
         return (emailheader.append(emailTable).append(errorDiv).append(emailButton));
     }
@@ -313,7 +325,7 @@ define('oxguard/settings/pane', [
             newpass2.css('background-color', 'white');
             var userdata = {
                     newpass: newpass.val(),
-                    oldpass: ($('input[name="oldpass"]').val() === undefined ? '' : $('input[name="oldpass"]').val().trim()),
+                    oldpass: ($('input[name="oldpass"]').val() === undefined ? '' : $('input[name="oldpass"]').val()),
                     user_id: ox.user_id,
                     sessionID: ox.session,
                     cid: ox.context_id,
@@ -372,7 +384,13 @@ define('oxguard/settings/pane', [
         id: 'oxguardsettings',
         draw: function () {
             var node = this;
-            draw (node);
+            if (util.isGuardLoaded()) {
+                draw (node);
+            } else {
+                util.addOnLoaded(function () {
+                    draw(node);
+                });
+            }
         },
         save: function () {
         }
@@ -391,7 +409,11 @@ define('oxguard/settings/pane', [
             node.append(addSettings());
         })
         .fail (function () {
-            node.append(setupGuard(node));
+            require(['io.ox/core/capabilities'], function (capabilities) {
+                if (capabilities.has('guard-mail') || capabilities.has('guard-drive')) {
+                    node.append(setupGuard(node));
+                }
+            });
             return;
         });
 
@@ -409,11 +431,15 @@ define('oxguard/settings/pane', [
         message.append(new HelpView({
             base: 'help-guard',
             iconClass: 'guardhelp',
-            href: 'ox.guard.user.sect.settings.security.html',
+            href: 'ox.guard.user.sect.usage.settings.security.html',
             tabindex: '-1'
         }).render().$el);
         var header = $('<h1>').append(message);
         holder.append(header);
         return (holder.append(createPasswordChange()).append(createPasswordReset()).append(createSecondaryChange()).append(createDeleteRecovery()));
     }
+
+    return {
+        updateEmail: updateEmail
+    };
 });
