@@ -1,12 +1,14 @@
 define('oxguard/tour/main', [
     'io.ox/core/tk/wizard',
+    'io.ox/core/tk/hotspot',
     'oxguard/oxguard_core',
     'oxguard/util',
     'io.ox/core/capabilities',
     'io.ox/backbone/mini-views/help',
+    'oxguard/core/createKeys',
     'settings!oxguard',
     'gettext!oxguard/tour'
-], function (Tour, core, util, capabilities, HelpView, settings, gt) {
+], function (Tour, hotspot, core, util, capabilities, HelpView, keys, settings, gt) {
     'use strict';
 
     function writeMail() {
@@ -70,7 +72,7 @@ define('oxguard/tour/main', [
                         //HACK: can not detect that mail compose window is rendered
                         composeApp.view.$el.addClass('og-ready');
                         window.setTimeout(function () {
-                            tour.addHotspot('.toggle-encryption', { 'top': 14, 'left': 14 });
+                            hotspot.add('.toggle-encryption', { 'top': 14, 'left': 14 });
                             composeApp.view.$el.find('.toggle-encryption .fa').click();
                         }, 500);
                     });
@@ -106,6 +108,9 @@ define('oxguard/tour/main', [
             })
             .waitFor('.oxguard_settings.password')
             .spotlight('.oxguard_settings.password')
+            .on('ready', function () {
+                $('.oxguard_settings').css('padding', '10px');
+            })
             .end()
         .step()
             .title((settings.get('advanced') ? gt.pgettext('tour', 'PGP Encryption Settings') : gt.pgettext('tour', 'Security Settings')))
@@ -120,6 +125,9 @@ define('oxguard/tour/main', [
             .waitFor('.oxguard_settings.defaults')
             .spotlight('.oxguard_settings.defaults')
             .hotspot('.oxguard_settings.defaults #pgpdefault', { 'top': 5, 'left': 5 })
+            .on('ready', function () {
+                $('.oxguard_settings').css('padding', '10px');
+            })
             .end()
         .step()
             .title(gt.pgettext('tour', 'Signature'))
@@ -179,7 +187,7 @@ define('oxguard/tour/main', [
             .on('wait', function () {
                 ox.ui.App.reuse(composeApp.cid);
                 window.setTimeout(function () {
-                    tour.addHotspot('.toggle-encryption', { 'top': 14, 'left': 14 });
+                    hotspot.add('.toggle-encryption', { 'top': 14, 'left': 14 });
                     composeApp.model.set('encrypt', false);
                 }, 500);
             })
@@ -192,13 +200,13 @@ define('oxguard/tour/main', [
             .content(gt.pgettext('tour', 'You can also protect your files. Just click on Encrypt and the selected file will be stored securely.'))
             .navigateTo('io.ox/files/main')
             .waitFor('.file-list-view')
-            .hotspot('.classic-toolbar a[data-action=encrypt]')
+            .hotspot('.classic-toolbar a[data-action=encrypt]', { 'top': 13, 'left': 10 })
             .on('wait', function () {
                 window.setTimeout(function () {
                     $('.file-list-view > .list-item.selectable:not(.file-type-folder):not(.file-type-guard):first').click();
                     window.setTimeout(function () {
                         $('.classic-toolbar [data-action=more] ~ ul').css('display', 'block');
-                        tour.addHotspot('.classic-toolbar a[data-action=encrypt]');
+                        hotspot.add('.classic-toolbar a[data-action=encrypt]', { 'top': 13, 'left': 10 });
                     }, 500);
                 }, 500);
             })
@@ -253,14 +261,14 @@ define('oxguard/tour/main', [
         var configured = util.isGuardConfigured();
 
         if (_.device('small') || _.device('smartphone')) {
-            return core.createKeys();
+            return keys.createKeys();
         }
 
         var tour = new Tour(),
-            model = new core.CreateKeysViewModel({
+            model = new keys.CreateKeysViewModel({
                 initialSetup: true
             }),
-            view = new core.CreateKeysView({
+            view = new keys.CreateKeysView({
                 model: model
             });
 
@@ -301,6 +309,13 @@ define('oxguard/tour/main', [
                     //HACK: no way to pause the wizard until some event
                     $('body').addClass('og-ready');
                 });
+                window.setTimeout(function () {
+                    if (_.device('desktop')) {
+                        $('#newogpassword').focus();
+                    } else {
+                        $('[type="password"]').removeAttr('readonly');  // Remove the read only but do not focus.  User needs to click for keyboard
+                    }
+                }, 1000);
             })
             .on('next', function () {
                 model.send();
