@@ -12,8 +12,9 @@
  */
 define('oxguard/util', [
 'mailvelope/main',
+'io.ox/core/capabilities',
 'settings!oxguard'
-], function (mapi, settings) {
+], function (mapi, capabilities, settings) {
     'use strict';
 
     var api = {};
@@ -28,6 +29,10 @@ define('oxguard/util', [
         return window.oxguarddata.passcode !== 'No Key';
     };
 
+    api.isMailvelope = function () {
+        return (settings.get('cryptoProvider') === 'mailvelope');
+    };
+
     api.hasSetupDone = function () {
         var def = $.Deferred();
         if (settings.get('cryptoProvider') === 'guard') {
@@ -57,6 +62,10 @@ define('oxguard/util', [
         return (def);
     };
 
+    api.hasCryptoCapability = function () {
+        return (capabilities.has('guard') || capabilities.has('mailvelope'));
+    }
+;
     api.isGuardEnabled = function () {
         return (settings.get('cryptoProvider') === 'guard');
     };
@@ -65,5 +74,20 @@ define('oxguard/util', [
         return (settings.get('cryptoProvider'));
     };
 
+    api.hasGuardMailCapability = function () {
+        return (capabilities.has('guard-mail'));
+    };
+
+    api.isGuardLoaded = function () {
+        return window.oxguarddata.loaded;
+    };
+
+    api.addOnLoaded = function (loadFunction) {
+        if (!window.oxguarddata.onload) {
+            window.oxguarddata.onload = [];
+        }
+        window.oxguarddata.onload.push(loadFunction);
+    };
+
     return api;
 });
