@@ -17,7 +17,8 @@ define('pgp_mail/toggle-encryption', [
         },
         className: 'toggle-encryption',
         events: {
-            'click i.fa': 'toggle'
+            'click i.fa': 'toggle',
+            'change:encrypt': 'changed'
         },
         toggle: function () {
             if (this.encryption_forced) {
@@ -26,25 +27,6 @@ define('pgp_mail/toggle-encryption', [
                 });
             } else {
                 this.model.set('encrypt', !this.model.get('encrypt'));
-                if (this.model.get('encrypt')) {
-                    showAttLink(this.view, false);
-                    checkAttLink(this.model);
-                    try {
-                        var fromArray = this.model.get('from');
-                        if (window.oxguarddata.primaryEmail !== undefined) {
-                            if (window.oxguarddata.primaryEmail !== fromArray[0][1]) {
-                                var warn = settings.get('warnEmailDifferent');
-                                if (warn === undefined || warn === false) {
-                                    displayWarning();
-                                }
-                            }
-                        }
-                    } catch (e) {
-                        console.log(e);
-                    }
-                } else {
-                    showAttLink(this.view, true);
-                }
             }
         },
         forceEncryption: function () {
@@ -61,17 +43,45 @@ define('pgp_mail/toggle-encryption', [
             }
             if (api.isMailvelopeSupported() || guard || this.encryption_forced)
                 {
+                if (!_.device('small'))
                 this.$el.empty().append(
                     $('<i class="fa fa-2x">')
                     .toggleClass('encrypted', !!this.model.get('encrypt'))
                 );
             }
+            if (_.device('small')) {
+                this.$el.addClass('mobile-toggle');
+            }
+            this.listenTo(this.model, 'change:encrypt', function () {
+                this.changed();
+            });
             return this;
         },
         noLinkMail: function (view) {
             this.view = view;
             checkAttLink (this.model, view);
             stopAttLink();
+        },
+        changed: function () {
+            if (this.model && this.model.get('encrypt')) {
+                showAttLink(this.view, false);
+                checkAttLink(this.model);
+                try {
+                    var fromArray = this.model.get('from');
+                    if (window.oxguarddata.primaryEmail !== undefined) {
+                        if (window.oxguarddata.primaryEmail !== fromArray[0][1]) {
+                            var warn = settings.get('warnEmailDifferent');
+                            if (warn === undefined || warn === false) {
+                                displayWarning();
+                            }
+                        }
+                    }
+                } catch (e) {
+                    console.log(e);
+                }
+            } else {
+                showAttLink(this.view, true);
+            }
         }
     });
 
