@@ -3,6 +3,15 @@ define([
 ],function (ToggleEncryption) {
     describe('Toggle Encryption Button', function () {
         describe('View', function () {
+            var deviceStub;
+            beforeEach(function () {
+                deviceStub = sinon.stub(_, 'device').withArgs('small').returns(false);
+                window.oxguarddata.settings.oxguard = true;
+            });
+            afterEach(function () {
+                _.device.restore();
+            });
+
             it('should render an icon', function () {
                 var v = new ToggleEncryption.View({
                     model: new Backbone.Model()
